@@ -84,6 +84,23 @@ class Scraper:
         self.error_period = error_period
         self._search_counter = 0
         self.running = True
+        """A Scraper which finds tests for us.
+
+        Args:
+            browser (Browser): the browser we use to do the scraping.
+
+            drivers (list[Driver]): the drivers to find tests for.
+
+            notify (callable): the function to call when we find something.  If
+                               unset we use `print`, so you should set this.
+                               Receives one argument, a str. (default=None)
+
+            reserve (bool): whether to reserve a test if we find it. (default=True)
+
+            short_notice (bool): whether to consider short notice tests. (default=True)
+
+            error_period (int): time in seconds to sleep when we have an error (default=30).
+        """
 
     def dvsa_disabled(self):
         return datetime.now() < datetime.combine(
@@ -385,13 +402,18 @@ class Scraper:
 
         return None, None
 
-    def time_to_next_event(self) -> int:
+    def time_to_next_event(self, elapsed: dt.timedelta = None) -> int:
         """Time to sleep between runs.
 
         Returns:
             time (int): time in seconds.
         """
-        return self.period * 60
+        subtract = elapsed.seconds if elapsed else 0
+        return max(self.period * 60 - elapsed, 0)
+
+    def error_callback(self):
+        """Run something when we have an error."""
+        pass
 
     def __call__(self):
         while True:
@@ -408,22 +430,33 @@ class Scraper:
 
             printed = False
             errs = deque([], maxlen=5)
+            searched, errored = 0, 0
 
             try:
                 with self._browser as browser:
                     while self.running:
                         for driver in self.drivers:
+                            start = datetime.now()
+                            self._logger.info(
+                                f"Finding tests for driver {driver.name} "
+                                f"run {searched +1}, of which {errored} errored."
+                            )
                             self.find_tests(browser, driver)
-                            period = self.time_to_next_event()
-                            self._logger.debug(f"Sleeping for {period}")
+                            end = datetime.now()
+                            period = self.time_to_next_event(elapsed=end - start)
+                            period = max(period - 5, 0)
+                            self._logger.debug(f"Sleeping for {period}s.")
                             spinner_sleep(period)
                             self._logger.debug(
-                                f"Sleeping for ~10s to introduce some randomness."
+                                f"Sleeping for ~5s to introduce some randomness."
                             )
-                            randsleep(10)
+                            randsleep(5)
+                            searched += 1
             except Exception as e:
+                errored += 1
                 errs.append(monotonic())
                 self._logger.exception(e)
+                self.error_callback()
                 randsleep(self.error_period)
 
             if len(errs) == 5 and errs[-1] - errs[0] < 10 * 60:
