@@ -28,6 +28,8 @@ def _start_detached(executable, *args, writer: multiprocessing.Pipe = None):
         kwargs.update(start_new_session=True)
 
     # run
+    if not executable.startswith('"'):
+        executable = f'"{executable}"'
     cmdline = " ".join([executable, *args])
     logger.debug(f"running chrome, cmdline is {cmdline}")
     PIPE = uc.dprocess.PIPE
@@ -62,6 +64,7 @@ class UndetectedBrowser(Browser):
 
         kwargs = {"options": chrome_options, "browser_executable_path": self._chrome}
         driver = UndetectedCaptchaChrome(**kwargs)
+        self._proc = uc.dprocess.REGISTERED[-1]
 
         driver.get(self._url)
         return driver
